/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_3Q_HPP_
#define _HEAVY_CONTEXT_WSTD_3Q_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvMath.h"
#include "HvControlSlice.h"
#include "HvSignalBiquad.h"
#include "HvControlSystem.h"
#include "HvControlVar.h"
#include "HvSignalVar.h"
#include "HvSignalLine.h"
#include "HvControlBinop.h"
#include "HvControlIf.h"
#include "HvControlCast.h"
#include "HvControlUnop.h"

class Heavy_WSTD_3Q : public HeavyContext {

 public:
  Heavy_WSTD_3Q(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_3Q();

  const char *getName() override { return "WSTD_3Q"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 6; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_LGXjhneP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5g5MTH2d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_L9GZBib5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Bj0VfxwX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0i9qxNvj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Oci2bq6w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_cAuVvKQw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ieh9YMaK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MFNUWxTN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_PbaB51Kw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_vbloet2a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Nu21tgQO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g03WmxFo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OLftARpX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Itiu7lEr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FjbydUUD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X8ORI05Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jSApNqsS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N50FGvEL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FL8HO5hM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HznVURQQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_sSlkirw1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d3am4Zqv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NI5mUzFw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QKPNEN9u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eTx8uQO1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2kUmddfC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EYBaaizm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V6M1Tatq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YGyURxfK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3xpjX3fn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_LMHNFnwM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_wlpFQM8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_lL4uLZU3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_sb1gbOuP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VFlMIy0S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_61SRpTWz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OBaz73Im_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XchoyIHk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MuM4CCyd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GJUobnQq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PBTX1Xup_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uccn0DKo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ozgzvXpr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rvFvLHDr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wrBNR9xw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OHXG7V3L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WDMKD9EM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y40VKQ2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7ApexT5V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LXwna7Ys_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8oaNItRo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ddKxq7GU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u9YFHbAJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yWyLQVcm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_b9S9gUPo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_47FIPqtC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_V9kiU7Lh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WefBefpA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t6F86zCJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AoYts7gF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JNLx4xYc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5IyAjkqz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bxoi9cFu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xbhRWnaJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aldxSRkx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_HoYsaPOn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DSBbcGtI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3risyPMs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hBJuAFVT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5DjfJHE6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_42U5cGc1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8IOdtA5O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Srk2vnag_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_l9zkJAz0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Al3RWN4j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BAGX6hrS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_Ekl0pJvI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_YDR9wsIr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_GPKKuYP9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_sYqsyGXp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_iIXgxAqF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jSzqSLOG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_mMt8JWEd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_FkbAUZup_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_C8H4OFZQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_HOQpaGpY_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_vVDqpwxE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TE3Upfy3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_StJLUfgK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_3DjmfQPN_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_oDWWWLTC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aNDBono4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JORtfkIX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gczp4t6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YI8vD9Pm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rPpVm4wZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yKdXOKsb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0uN6TtXE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XLLUMBVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_EP8QXCV4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_fCRIMZuV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kG2cCaY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Lk8kVwAb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H3QgnHtS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u5S2Tx1E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_O0cffu3W_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_OLoBqgfd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_JnUTFYca_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2meQBlLv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2PjyOsoU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HDgxjUdF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pdPCktbK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_a8L3xy4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mNQjYlFf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0ksGXp4g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UnfX4mIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OhmSgG8Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zb6UJeK5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xpkX2kJt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fwDCPCzd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9pNBDArR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lxORPxHe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rgfz959q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vBwkg1DG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oWhd69N4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Tm2oaWTz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yFgi1vV2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bWYDv5UV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_0FcE35Fc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vFToja05_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K3gJ2MZ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bDi4Z0IG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d7CUZJkT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JyX7TJqK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q0vBlk51_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_as4EJaQo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4hutjTPH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MXCepxxr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LEFqfmqW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HKSx4J6u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DlHuwtHB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GLwL7ijM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XiWyqJ46_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_n8dtzb7M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yKs1HyD9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7bRT82nM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LLckCzsN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DdABQp91_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KNSkmC8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_bFviw2Ks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TBoczRwF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9PkYpYvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ni91pIWN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yxux7teS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ol5Wuoj8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dyAsYvi2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_hLeO5Ghl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GkmSJKUj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SjiTMk7m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8pH0knpa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_C8y571A0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BqugSVdC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ARyFzBsy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_igtN67Xo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SorNKbVN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kGnhh8ls_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zysghgua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eVcG6C95_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b5whqJsZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tyhhezCV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8N2fbHkN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WERiqjkE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_hjZbtsYB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r3aZKZZp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_2dCk7T7j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Eag805SN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_w4XItnEv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_25n3BLof_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FHuMxFWH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nxLelBY2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ZOzV51un_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_lSg880Mg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HFEhOe5I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GsbYaYFw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HcQH5qDM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pxgV4uHR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wfhNMe6V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oKgHss9D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9AqJmsiD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aQld2cTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MeVkSNgU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FhUGgLni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mr8nCAHj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yPANtIgY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2ccOVu0p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_715RQcOq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tikVf372_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_vzx3wpfj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_f43oLVrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nS2b7Fey_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tGiLA0Iy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QrKB2lnJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_b1eXFIl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_10xAvRpN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Y6tm27sh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ojo5CBXa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_17HH795e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_DtX7ZjT7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1WWdih8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KX2GWfJn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KfmUakTz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ob9kWn2z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cz6oN4dX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_R94MAZJ6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_wwHCkwf6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K0ILDjQy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PMqWv4EF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3DPyW2p6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MvQMZbiV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UvoUfzk7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_n9MvuERz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ps6neYiq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0ceVDqXw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yzO3fWm5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1u2XtI9Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rv63AVXc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zaTaVJ9j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0RDI5WV5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OJI3ARSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BfXe7oXk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ywqQmaRP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_j6Vk5qis_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CjeWJXy9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Tz8HD57E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aJRgSblb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GECSNKhw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Tx8phICR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_uIdNhyo9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GRYZvC5Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_MVazLbqu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A8jFYBC8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tt9f8ncp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5wb1fobb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SnFOZLW3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_x0Ocqt7C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qewGKoJB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wNSOB0J0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fOXcc63n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4Z7awi9Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ufzdYQKU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yGDPbZok_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IKjNumpf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jMiEQjeh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CxvfkpFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oyk8XUa0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_frvcancZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8kZ7d33P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LMB0GpGf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FSoUXdQ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qoBUMsZU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zlbJkJkr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L0vpaW3h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_y1BBRYrb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kxXgSl24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_WTx3KXlI_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_yEMoWvfz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zoksfoLq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_OYGbpLf8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NsYu8acF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_BT6hZWNI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1HGJDVzq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IdxylQwP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0XS44ZYh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RHznc6I2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_aSwd91Ek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_QHZ2wJoh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DgNNHFjg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_08XEuZ1V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_w8yHFTuC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pPXktfzY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MvOIwmSc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PVof9U7N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yyLEIXPS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Ir1Kqqr9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2hnJtD9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f2hC6Eyq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y35BAjMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_htxZgrVO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9NMUKKgH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_X610rijU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1nnFBetS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oB7tcJ19_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_jHi7DsL6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_SisU4XzM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zpE7HXne_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_au0gAn56_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BaV1E6D7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UGnKFY2y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RSV0cyTW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JT1vzZUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UaifJNKr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pGKyWQIu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SpxUgiLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0jNen0pd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0YXph04X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_t5fVf6Ij_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_8sXpCqOB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KokH4pqt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_13KxfUAB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2BOsQ9qa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_atd6vfH4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hSvhZ5dO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mmnYDDww_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xX3pbldQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Tv3krW75_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_0Xk2V2y1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_dbC7btRl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ktSoCtqb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hX2xMdKj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8KzQYPoh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NHgg48Hu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XskYBloK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8s3pMNn0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b3Mnqn5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qAuFNGsB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9nynMn8N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_DRw49dwD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7VfK3jcE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9IAXVfBc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aKgmbSKD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n2qG79Yq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1NJe2IKg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_m7rzW7vb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zFrvDH4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UkS2Mx42_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nyajlf0t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MKRaMSPm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_K7kYkfCV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Rzaip1iC_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_QsnD6i4r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lCYd6rv9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Q6VJ5g4g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_D4PNvRwv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_6v364kQE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_qLK92Rrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_R5wLrbAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ThylinR7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_X69u879E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rNF79CL7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gmmtITMd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_v3613g7s_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_rS7mCTJj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NdVHtBcs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sdNbI0b3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NCHzJaxi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LdyUVdDz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dK0BLpek_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nxwcJxcL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bGYtWf5R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_BtEfiHfM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_SAEVFJog_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_HTZwc2o6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Suo9fre2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rrhv0UXM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oMIqFs0Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_boSCMrB2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_T7EBcG1b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_U8ZN6OAV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_3Vj7NhPP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Mka4kipj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wyYwV4l4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Oh9mMqZr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_risFYeVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3aalGI24_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_RjiL4FIV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MuBb5IxJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_l8kAavAe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_36fxeYz9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4KBh9ojg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZmRPEq3e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6799I08L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KqoRWKV7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SnS3HUlu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B8GCaKwJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PghDLKdM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_y8EhCli1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GJiAwy9g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xMIzOY1n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_vCgjJ8uQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_y7d2FrgL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nZhdqPYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QcljJxtY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rfhq2M0o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iIVB2FiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0xausIpD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tbhKtUjn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EcrnTdsE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Og5FZMCl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lUXsE1vQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YL3EYcp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eUUfcVrn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_93ksQO2h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_iaM1aSN0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_N6FIeToV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZAQfSNEL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_dNnvUBfP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Q6PUEpL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2dGGExRD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ch82K78o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RKiYss8y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tK3lNg1a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DJ6CVTy8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HeshWTw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zfLsR2Cj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I8z5jLG6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_paPTeAEy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EV98i8vH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_C3y6sTZL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TWpZTFe9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_UzwoCcaF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CokUg3Lp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E6L6ciRr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FoDbPJ17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_scjTbsJP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_MwEdkuyl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_Ci17H1UY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MJFAQWnb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_80wdgHCf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wtUT1C2r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gEkci10s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xYesSGj6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fr5iFwue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rs1SktHX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JRYwJMcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TID7HMZV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1QLDgCXn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_xDl3xNVo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_DiRAn7Fe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tyNhQEv4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OMaw3yuz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_b2FCvSUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cMjEnKAF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_C205HoBd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9tB2eHmU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xnzFZ511_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_K7O7r4cr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yteVCg4h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TMh35qSg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_00rMYEdE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YCrlYC0Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bMR794Iq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WsXpdKLr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E8P6soqZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Nhwdeego_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9FW719np_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_THc1NrrP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Td4TIDO6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hSPjT28c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VDhPe24G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_htBgNyOy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9K4GFJqn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rNbXFJbH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_43mJk8WI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pLe0b2Ue_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E0trfQcj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dOqLQITM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_s8hkq9YP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_2l28zcGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_11FctBLV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XXyasYNZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E20h2L4X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_AeUlrpEJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zob6arI0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iIOvTDEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_k5iWIrkh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_xIlX3ALY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SX5ryDxD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ls2yY01v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SjzML7x7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MT7n3HTH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SBpE34YZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q0lPu0hK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_lQG1Dz0S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CCr9o0bA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YyIxYwCs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qulj90ks_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_I4Ly0VUW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gXlQy4VI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_e6rpApYb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZE8SjIts_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EqllBlRF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2nhxGxsD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ctu069Gc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XGjv7Ckc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YwJ7t0Kc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tXYpj6Yu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_NATbtMbj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Y2gLoynl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VYg8CffU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Blwrnwyt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_W8lm1t0p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uWt8Rroy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QIpuN38m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yYzq8F5X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0Etyk6PC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dXb4GO0o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EDWTUekU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZkOPTdO3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0XOmaNcQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jN7KFh8u_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qp3GGFqS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WNUfsSqX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KSwM1w8s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nTX4kp0i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rbqFDDLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CKChnbop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uf3RJuBX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wo4CLwzw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RiDHmx5Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ASUMhaIg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EGGQgQDY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_svyAIFcs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LHL2hnlZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bgj2NxPx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Pssal8Sn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_JQYK1JEp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CIxvh0kQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_ub5GZ4A1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_SrG2WaVN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Uxmui9W4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KYk95mLX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7X27LRrc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cE1phrK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yq95Kc4Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_es3h5HPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_p8I7hwgs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cge3fS3m_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IWPgBiYw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8UI2YmXU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vJwJSr26_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_88IM9CrB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_NCd0dEPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fwRtVHjo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6haLAG35_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_DUt6ymjh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1xe8x1Gf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XlagLmwT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZTh4Xi6o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pn0KeOaP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_uOrms6QN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZFdViKOZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PUeLZBhv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ztQKGfWL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9aGm8ix4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R4ILd527_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sqRcNKIK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7eUIoCd7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_TzHdwvGg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Z0wnaUYG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_QsckhbpR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_CnuHveKW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ZhRsAVrj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mTfbEyLU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_n8zMVUzu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JPYfLtGj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Epu2GpzV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WLJrKhzg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eeGgnpuB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_KnwVdMJR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4HnKR9eN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iowdBzeS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_cqhAUHVp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_tIcOo80G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_RomVcN9E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_1TOqqhdW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_z0U6KJ5i_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_68EiZkHo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_WpS5hsq4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Re0s4gjW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_7cLiOR54_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_iHAWnjhd;
  SignalLine sLine_v9q9Nvkl;
  SignalLine sLine_Gq8kq6bj;
  SignalLine sLine_qmEGzyOo;
  SignalLine sLine_1oazJ2JW;
  SignalBiquad sBiquad_s_DyLaJ269;
  SignalLine sLine_eR7ZcX6W;
  SignalLine sLine_EppcuUID;
  SignalLine sLine_wGcy1KPF;
  SignalLine sLine_Yhy2wQ9Y;
  SignalBiquad sBiquad_s_0Ncm1ImX;
  SignalLine sLine_PfN9zJXM;
  SignalLine sLine_ywm8N8Ug;
  SignalLine sLine_hpyNO9jx;
  SignalLine sLine_ULzSpYVr;
  SignalLine sLine_KzYakTuc;
  SignalBiquad sBiquad_s_g2GvB5Ri;
  SignalLine sLine_hFefh3BO;
  SignalLine sLine_yPtnnMvF;
  SignalLine sLine_DKt35oPf;
  SignalLine sLine_Ppc3quhn;
  SignalLine sLine_vkeTA81Q;
  SignalBiquad sBiquad_s_qMltZ4Me;
  SignalLine sLine_J8tltp85;
  SignalLine sLine_CcCXTdn6;
  SignalLine sLine_o4wkmNiL;
  SignalLine sLine_uctpVg2V;
  SignalBiquad sBiquad_s_moMyHu2Y;
  SignalLine sLine_dCF53TD5;
  SignalLine sLine_m4Y6EUBk;
  SignalLine sLine_QNMgRTPC;
  SignalLine sLine_8ZooiglC;
  SignalLine sLine_OhoyiwcX;
  SignalBiquad sBiquad_s_HfgzVHKd;
  ControlVar cVar_LGXjhneP;
  ControlVar cVar_5g5MTH2d;
  ControlVar cVar_L9GZBib5;
  ControlVar cVar_Bj0VfxwX;
  ControlSlice cSlice_Oci2bq6w;
  ControlVar cVar_cAuVvKQw;
  ControlVar cVar_MFNUWxTN;
  ControlIf cIf_PbaB51Kw;
  ControlIf cIf_vbloet2a;
  ControlBinop cBinop_g03WmxFo;
  ControlBinop cBinop_OLftARpX;
  ControlBinop cBinop_X8ORI05Y;
  ControlBinop cBinop_jSApNqsS;
  ControlBinop cBinop_FL8HO5hM;
  ControlIf cIf_HznVURQQ;
  ControlBinop cBinop_sSlkirw1;
  ControlBinop cBinop_d3am4Zqv;
  ControlBinop cBinop_QKPNEN9u;
  ControlBinop cBinop_eTx8uQO1;
  ControlBinop cBinop_2kUmddfC;
  ControlVar cVar_LMHNFnwM;
  ControlIf cIf_wlpFQM8c;
  ControlIf cIf_lL4uLZU3;
  ControlBinop cBinop_VFlMIy0S;
  ControlBinop cBinop_61SRpTWz;
  ControlBinop cBinop_MuM4CCyd;
  ControlBinop cBinop_GJUobnQq;
  ControlBinop cBinop_Uccn0DKo;
  ControlIf cIf_ozgzvXpr;
  ControlBinop cBinop_rvFvLHDr;
  ControlBinop cBinop_wrBNR9xw;
  ControlBinop cBinop_WDMKD9EM;
  ControlBinop cBinop_y40VKQ2E;
  ControlBinop cBinop_7ApexT5V;
  ControlVar cVar_yWyLQVcm;
  ControlIf cIf_b9S9gUPo;
  ControlIf cIf_47FIPqtC;
  ControlBinop cBinop_WefBefpA;
  ControlBinop cBinop_t6F86zCJ;
  ControlBinop cBinop_5IyAjkqz;
  ControlBinop cBinop_Bxoi9cFu;
  ControlBinop cBinop_aldxSRkx;
  ControlIf cIf_HoYsaPOn;
  ControlBinop cBinop_DSBbcGtI;
  ControlBinop cBinop_3risyPMs;
  ControlBinop cBinop_5DjfJHE6;
  ControlBinop cBinop_42U5cGc1;
  ControlBinop cBinop_8IOdtA5O;
  ControlIf cIf_Ekl0pJvI;
  ControlSlice cSlice_GPKKuYP9;
  ControlVar cVar_sYqsyGXp;
  ControlSlice cSlice_mMt8JWEd;
  ControlVar cVar_FkbAUZup;
  ControlSlice cSlice_vVDqpwxE;
  ControlVar cVar_TE3Upfy3;
  ControlSlice cSlice_oDWWWLTC;
  ControlVar cVar_aNDBono4;
  ControlBinop cBinop_Lk8kVwAb;
  ControlBinop cBinop_u5S2Tx1E;
  ControlBinop cBinop_O0cffu3W;
  ControlBinop cBinop_2meQBlLv;
  ControlBinop cBinop_2PjyOsoU;
  ControlBinop cBinop_HDgxjUdF;
  ControlBinop cBinop_pdPCktbK;
  ControlBinop cBinop_a8L3xy4b;
  ControlVar cVar_mNQjYlFf;
  ControlBinop cBinop_0ksGXp4g;
  ControlBinop cBinop_UnfX4mIg;
  ControlBinop cBinop_OhmSgG8Y;
  ControlBinop cBinop_zb6UJeK5;
  ControlBinop cBinop_xpkX2kJt;
  ControlBinop cBinop_fwDCPCzd;
  ControlBinop cBinop_9pNBDArR;
  ControlBinop cBinop_Rgfz959q;
  ControlVar cVar_vBwkg1DG;
  ControlVar cVar_oWhd69N4;
  ControlBinop cBinop_bDi4Z0IG;
  ControlBinop cBinop_d7CUZJkT;
  ControlBinop cBinop_JyX7TJqK;
  ControlBinop cBinop_as4EJaQo;
  ControlBinop cBinop_4hutjTPH;
  ControlBinop cBinop_MXCepxxr;
  ControlBinop cBinop_LEFqfmqW;
  ControlBinop cBinop_HKSx4J6u;
  ControlBinop cBinop_DlHuwtHB;
  ControlBinop cBinop_8pH0knpa;
  ControlBinop cBinop_BqugSVdC;
  ControlBinop cBinop_ARyFzBsy;
  ControlBinop cBinop_kGnhh8ls;
  ControlBinop cBinop_Zysghgua;
  ControlBinop cBinop_eVcG6C95;
  ControlBinop cBinop_b5whqJsZ;
  ControlBinop cBinop_tyhhezCV;
  ControlBinop cBinop_8N2fbHkN;
  ControlBinop cBinop_WERiqjkE;
  ControlBinop cBinop_r3aZKZZp;
  ControlVar cVar_2dCk7T7j;
  ControlVar cVar_Eag805SN;
  ControlVar cVar_w4XItnEv;
  ControlBinop cBinop_GsbYaYFw;
  ControlBinop cBinop_HcQH5qDM;
  ControlBinop cBinop_pxgV4uHR;
  ControlBinop cBinop_oKgHss9D;
  ControlBinop cBinop_9AqJmsiD;
  ControlBinop cBinop_aQld2cTH;
  ControlBinop cBinop_MeVkSNgU;
  ControlBinop cBinop_FhUGgLni;
  ControlBinop cBinop_KX2GWfJn;
  ControlBinop cBinop_Ob9kWn2z;
  ControlBinop cBinop_cz6oN4dX;
  ControlBinop cBinop_K0ILDjQy;
  ControlBinop cBinop_PMqWv4EF;
  ControlBinop cBinop_3DPyW2p6;
  ControlBinop cBinop_MvQMZbiV;
  ControlBinop cBinop_UvoUfzk7;
  ControlBinop cBinop_ps6neYiq;
  ControlBinop cBinop_yzO3fWm5;
  ControlBinop cBinop_1u2XtI9Q;
  ControlBinop cBinop_zaTaVJ9j;
  ControlBinop cBinop_0RDI5WV5;
  ControlBinop cBinop_OJI3ARSP;
  ControlBinop cBinop_ywqQmaRP;
  ControlVar cVar_j6Vk5qis;
  ControlVar cVar_CjeWJXy9;
  ControlVar cVar_Tz8HD57E;
  ControlBinop cBinop_A8jFYBC8;
  ControlBinop cBinop_tt9f8ncp;
  ControlBinop cBinop_5wb1fobb;
  ControlBinop cBinop_x0Ocqt7C;
  ControlBinop cBinop_qewGKoJB;
  ControlBinop cBinop_wNSOB0J0;
  ControlBinop cBinop_fOXcc63n;
  ControlBinop cBinop_4Z7awi9Z;
  ControlBinop cBinop_ufzdYQKU;
  ControlBinop cBinop_zlbJkJkr;
  ControlBinop cBinop_y1BBRYrb;
  ControlBinop cBinop_kxXgSl24;
  SignalVarf sVarf_GnXgd6sr;
  SignalVarf sVarf_LT35FONL;
  SignalVarf sVarf_h9F5UT06;
  ControlSlice cSlice_yEMoWvfz;
  ControlVar cVar_zoksfoLq;
  ControlVar cVar_NsYu8acF;
  ControlIf cIf_BT6hZWNI;
  ControlIf cIf_1HGJDVzq;
  ControlBinop cBinop_0XS44ZYh;
  ControlBinop cBinop_RHznc6I2;
  ControlBinop cBinop_DgNNHFjg;
  ControlBinop cBinop_08XEuZ1V;
  ControlBinop cBinop_pPXktfzY;
  ControlIf cIf_MvOIwmSc;
  ControlBinop cBinop_PVof9U7N;
  ControlBinop cBinop_yyLEIXPS;
  ControlBinop cBinop_2hnJtD9o;
  ControlBinop cBinop_f2hC6Eyq;
  ControlBinop cBinop_Y35BAjMB;
  ControlVar cVar_oB7tcJ19;
  ControlIf cIf_jHi7DsL6;
  ControlIf cIf_SisU4XzM;
  ControlBinop cBinop_au0gAn56;
  ControlBinop cBinop_BaV1E6D7;
  ControlBinop cBinop_JT1vzZUW;
  ControlBinop cBinop_UaifJNKr;
  ControlBinop cBinop_SpxUgiLw;
  ControlIf cIf_0jNen0pd;
  ControlBinop cBinop_0YXph04X;
  ControlBinop cBinop_t5fVf6Ij;
  ControlBinop cBinop_KokH4pqt;
  ControlBinop cBinop_13KxfUAB;
  ControlBinop cBinop_2BOsQ9qa;
  ControlVar cVar_Tv3krW75;
  ControlIf cIf_0Xk2V2y1;
  ControlIf cIf_dbC7btRl;
  ControlBinop cBinop_hX2xMdKj;
  ControlBinop cBinop_8KzQYPoh;
  ControlBinop cBinop_8s3pMNn0;
  ControlBinop cBinop_b3Mnqn5g;
  ControlBinop cBinop_9nynMn8N;
  ControlIf cIf_DRw49dwD;
  ControlBinop cBinop_7VfK3jcE;
  ControlBinop cBinop_9IAXVfBc;
  ControlBinop cBinop_n2qG79Yq;
  ControlBinop cBinop_1NJe2IKg;
  ControlBinop cBinop_m7rzW7vb;
  ControlIf cIf_K7kYkfCV;
  ControlSlice cSlice_QsnD6i4r;
  ControlVar cVar_lCYd6rv9;
  ControlSlice cSlice_6v364kQE;
  ControlVar cVar_qLK92Rrn;
  ControlSlice cSlice_X69u879E;
  ControlVar cVar_rNF79CL7;
  ControlSlice cSlice_rS7mCTJj;
  ControlVar cVar_NdVHtBcs;
  ControlBinop cBinop_Rrhv0UXM;
  ControlBinop cBinop_boSCMrB2;
  ControlBinop cBinop_T7EBcG1b;
  ControlBinop cBinop_Mka4kipj;
  ControlBinop cBinop_wyYwV4l4;
  ControlBinop cBinop_Oh9mMqZr;
  ControlBinop cBinop_risFYeVW;
  ControlBinop cBinop_3aalGI24;
  ControlVar cVar_RjiL4FIV;
  ControlBinop cBinop_MuBb5IxJ;
  ControlBinop cBinop_l8kAavAe;
  ControlBinop cBinop_36fxeYz9;
  ControlBinop cBinop_4KBh9ojg;
  ControlBinop cBinop_ZmRPEq3e;
  ControlBinop cBinop_6799I08L;
  ControlBinop cBinop_KqoRWKV7;
  ControlBinop cBinop_B8GCaKwJ;
  ControlVar cVar_PghDLKdM;
  ControlVar cVar_y8EhCli1;
  ControlBinop cBinop_rfhq2M0o;
  ControlBinop cBinop_iIVB2FiY;
  ControlBinop cBinop_0xausIpD;
  ControlBinop cBinop_EcrnTdsE;
  ControlBinop cBinop_Og5FZMCl;
  ControlBinop cBinop_lUXsE1vQ;
  ControlBinop cBinop_YL3EYcp6;
  ControlBinop cBinop_eUUfcVrn;
  ControlBinop cBinop_93ksQO2h;
  ControlBinop cBinop_CokUg3Lp;
  ControlBinop cBinop_FoDbPJ17;
  ControlBinop cBinop_scjTbsJP;
  ControlBinop cBinop_MJFAQWnb;
  ControlBinop cBinop_80wdgHCf;
  ControlBinop cBinop_wtUT1C2r;
  ControlBinop cBinop_gEkci10s;
  ControlBinop cBinop_xYesSGj6;
  ControlBinop cBinop_Fr5iFwue;
  ControlBinop cBinop_Rs1SktHX;
  ControlBinop cBinop_TID7HMZV;
  ControlVar cVar_1QLDgCXn;
  ControlVar cVar_xDl3xNVo;
  ControlVar cVar_DiRAn7Fe;
  ControlBinop cBinop_xnzFZ511;
  ControlBinop cBinop_K7O7r4cr;
  ControlBinop cBinop_yteVCg4h;
  ControlBinop cBinop_00rMYEdE;
  ControlBinop cBinop_YCrlYC0Q;
  ControlBinop cBinop_bMR794Iq;
  ControlBinop cBinop_WsXpdKLr;
  ControlBinop cBinop_E8P6soqZ;
  ControlBinop cBinop_E20h2L4X;
  ControlBinop cBinop_Zob6arI0;
  ControlBinop cBinop_iIOvTDEO;
  ControlBinop cBinop_SX5ryDxD;
  ControlBinop cBinop_Ls2yY01v;
  ControlBinop cBinop_SjzML7x7;
  ControlBinop cBinop_MT7n3HTH;
  ControlBinop cBinop_SBpE34YZ;
  ControlBinop cBinop_lQG1Dz0S;
  ControlBinop cBinop_YyIxYwCs;
  ControlBinop cBinop_Qulj90ks;
  ControlBinop cBinop_gXlQy4VI;
  ControlBinop cBinop_e6rpApYb;
  ControlBinop cBinop_ZE8SjIts;
  ControlBinop cBinop_2nhxGxsD;
  ControlVar cVar_Ctu069Gc;
  ControlVar cVar_XGjv7Ckc;
  ControlVar cVar_YwJ7t0Kc;
  ControlBinop cBinop_uWt8Rroy;
  ControlBinop cBinop_QIpuN38m;
  ControlBinop cBinop_yYzq8F5X;
  ControlBinop cBinop_dXb4GO0o;
  ControlBinop cBinop_EDWTUekU;
  ControlBinop cBinop_ZkOPTdO3;
  ControlBinop cBinop_0XOmaNcQ;
  ControlBinop cBinop_jN7KFh8u;
  ControlBinop cBinop_qp3GGFqS;
  ControlBinop cBinop_svyAIFcs;
  ControlBinop cBinop_bgj2NxPx;
  ControlBinop cBinop_Pssal8Sn;
  SignalVarf sVarf_3WzIuWuY;
  SignalVarf sVarf_BurItLyE;
  SignalVarf sVarf_l8fHoiTF;
  ControlVar cVar_JQYK1JEp;
  ControlVar cVar_CIxvh0kQ;
  ControlBinop cBinop_cE1phrK6;
  ControlBinop cBinop_yq95Kc4Z;
  ControlBinop cBinop_es3h5HPz;
  ControlBinop cBinop_Cge3fS3m;
  ControlBinop cBinop_IWPgBiYw;
  ControlBinop cBinop_8UI2YmXU;
  ControlBinop cBinop_vJwJSr26;
};

#endif // _HEAVY_CONTEXT_WSTD_3Q_HPP_
