/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_3Q.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_3Q *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_3Q_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_3Q));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_3Q(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_3Q_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_3Q();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_3Q::Heavy_WSTD_3Q(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_iHAWnjhd);
  numBytes += sLine_init(&sLine_v9q9Nvkl);
  numBytes += sLine_init(&sLine_Gq8kq6bj);
  numBytes += sLine_init(&sLine_qmEGzyOo);
  numBytes += sLine_init(&sLine_1oazJ2JW);
  numBytes += sBiquad_init(&sBiquad_s_DyLaJ269);
  numBytes += sLine_init(&sLine_eR7ZcX6W);
  numBytes += sLine_init(&sLine_EppcuUID);
  numBytes += sLine_init(&sLine_wGcy1KPF);
  numBytes += sLine_init(&sLine_Yhy2wQ9Y);
  numBytes += sBiquad_init(&sBiquad_s_0Ncm1ImX);
  numBytes += sLine_init(&sLine_PfN9zJXM);
  numBytes += sLine_init(&sLine_ywm8N8Ug);
  numBytes += sLine_init(&sLine_hpyNO9jx);
  numBytes += sLine_init(&sLine_ULzSpYVr);
  numBytes += sLine_init(&sLine_KzYakTuc);
  numBytes += sBiquad_init(&sBiquad_s_g2GvB5Ri);
  numBytes += sLine_init(&sLine_hFefh3BO);
  numBytes += sLine_init(&sLine_yPtnnMvF);
  numBytes += sLine_init(&sLine_DKt35oPf);
  numBytes += sLine_init(&sLine_Ppc3quhn);
  numBytes += sLine_init(&sLine_vkeTA81Q);
  numBytes += sBiquad_init(&sBiquad_s_qMltZ4Me);
  numBytes += sLine_init(&sLine_J8tltp85);
  numBytes += sLine_init(&sLine_CcCXTdn6);
  numBytes += sLine_init(&sLine_o4wkmNiL);
  numBytes += sLine_init(&sLine_uctpVg2V);
  numBytes += sBiquad_init(&sBiquad_s_moMyHu2Y);
  numBytes += sLine_init(&sLine_dCF53TD5);
  numBytes += sLine_init(&sLine_m4Y6EUBk);
  numBytes += sLine_init(&sLine_QNMgRTPC);
  numBytes += sLine_init(&sLine_8ZooiglC);
  numBytes += sLine_init(&sLine_OhoyiwcX);
  numBytes += sBiquad_init(&sBiquad_s_HfgzVHKd);
  numBytes += cVar_init_f(&cVar_LGXjhneP, 0.0f);
  numBytes += cVar_init_f(&cVar_5g5MTH2d, 0.0f);
  numBytes += cVar_init_f(&cVar_L9GZBib5, 0.0f);
  numBytes += cVar_init_f(&cVar_Bj0VfxwX, 0.0f);
  numBytes += cSlice_init(&cSlice_Oci2bq6w, 1, -1);
  numBytes += cVar_init_f(&cVar_cAuVvKQw, 1337.0f);
  numBytes += cVar_init_f(&cVar_MFNUWxTN, 0.0f);
  numBytes += cIf_init(&cIf_PbaB51Kw, false);
  numBytes += cIf_init(&cIf_vbloet2a, false);
  numBytes += cBinop_init(&cBinop_g03WmxFo, 0.0f); // __pow
  numBytes += cIf_init(&cIf_HznVURQQ, false);
  numBytes += cBinop_init(&cBinop_QKPNEN9u, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_eTx8uQO1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2kUmddfC, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_LMHNFnwM, 0.0f);
  numBytes += cIf_init(&cIf_wlpFQM8c, false);
  numBytes += cIf_init(&cIf_lL4uLZU3, false);
  numBytes += cBinop_init(&cBinop_VFlMIy0S, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ozgzvXpr, false);
  numBytes += cBinop_init(&cBinop_WDMKD9EM, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_y40VKQ2E, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_7ApexT5V, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_yWyLQVcm, 0.0f);
  numBytes += cIf_init(&cIf_b9S9gUPo, false);
  numBytes += cIf_init(&cIf_47FIPqtC, false);
  numBytes += cBinop_init(&cBinop_WefBefpA, 0.0f); // __pow
  numBytes += cIf_init(&cIf_HoYsaPOn, false);
  numBytes += cBinop_init(&cBinop_5DjfJHE6, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_42U5cGc1, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8IOdtA5O, -15.0f); // __eq
  numBytes += cIf_init(&cIf_Ekl0pJvI, false);
  numBytes += cSlice_init(&cSlice_GPKKuYP9, 1, -1);
  numBytes += cVar_init_f(&cVar_sYqsyGXp, 0.0f);
  numBytes += cSlice_init(&cSlice_mMt8JWEd, 1, -1);
  numBytes += cVar_init_f(&cVar_FkbAUZup, 0.0f);
  numBytes += cSlice_init(&cSlice_vVDqpwxE, 1, -1);
  numBytes += cVar_init_f(&cVar_TE3Upfy3, 0.0f);
  numBytes += cSlice_init(&cSlice_oDWWWLTC, 1, -1);
  numBytes += cVar_init_f(&cVar_aNDBono4, 0.313f);
  numBytes += cBinop_init(&cBinop_u5S2Tx1E, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_O0cffu3W, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_mNQjYlFf, 0.0f);
  numBytes += cVar_init_f(&cVar_vBwkg1DG, 1337.0f);
  numBytes += cVar_init_f(&cVar_oWhd69N4, 0.3f);
  numBytes += cBinop_init(&cBinop_d7CUZJkT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4hutjTPH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MXCepxxr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_LEFqfmqW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_HKSx4J6u, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DlHuwtHB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BqugSVdC, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ARyFzBsy, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2dCk7T7j, 0.0f);
  numBytes += cVar_init_f(&cVar_Eag805SN, 1337.0f);
  numBytes += cVar_init_f(&cVar_w4XItnEv, 0.313f);
  numBytes += cBinop_init(&cBinop_HcQH5qDM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9AqJmsiD, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aQld2cTH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MeVkSNgU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FhUGgLni, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Ob9kWn2z, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_cz6oN4dX, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_j6Vk5qis, 0.0f);
  numBytes += cVar_init_f(&cVar_CjeWJXy9, 1037.0f);
  numBytes += cVar_init_f(&cVar_Tz8HD57E, 0.4f);
  numBytes += cBinop_init(&cBinop_tt9f8ncp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qewGKoJB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_wNSOB0J0, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_fOXcc63n, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4Z7awi9Z, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ufzdYQKU, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_GnXgd6sr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_LT35FONL, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_h9F5UT06, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_yEMoWvfz, 1, -1);
  numBytes += cVar_init_f(&cVar_zoksfoLq, 1337.0f);
  numBytes += cVar_init_f(&cVar_NsYu8acF, 0.0f);
  numBytes += cIf_init(&cIf_BT6hZWNI, false);
  numBytes += cIf_init(&cIf_1HGJDVzq, false);
  numBytes += cBinop_init(&cBinop_0XS44ZYh, 0.0f); // __pow
  numBytes += cIf_init(&cIf_MvOIwmSc, false);
  numBytes += cBinop_init(&cBinop_2hnJtD9o, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_f2hC6Eyq, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_Y35BAjMB, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_oB7tcJ19, 0.0f);
  numBytes += cIf_init(&cIf_jHi7DsL6, false);
  numBytes += cIf_init(&cIf_SisU4XzM, false);
  numBytes += cBinop_init(&cBinop_au0gAn56, 0.0f); // __pow
  numBytes += cIf_init(&cIf_0jNen0pd, false);
  numBytes += cBinop_init(&cBinop_KokH4pqt, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_13KxfUAB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_2BOsQ9qa, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Tv3krW75, 0.0f);
  numBytes += cIf_init(&cIf_0Xk2V2y1, false);
  numBytes += cIf_init(&cIf_dbC7btRl, false);
  numBytes += cBinop_init(&cBinop_hX2xMdKj, 0.0f); // __pow
  numBytes += cIf_init(&cIf_DRw49dwD, false);
  numBytes += cBinop_init(&cBinop_n2qG79Yq, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_1NJe2IKg, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_m7rzW7vb, -15.0f); // __eq
  numBytes += cIf_init(&cIf_K7kYkfCV, false);
  numBytes += cSlice_init(&cSlice_QsnD6i4r, 1, -1);
  numBytes += cVar_init_f(&cVar_lCYd6rv9, 0.0f);
  numBytes += cSlice_init(&cSlice_6v364kQE, 1, -1);
  numBytes += cVar_init_f(&cVar_qLK92Rrn, 0.0f);
  numBytes += cSlice_init(&cSlice_X69u879E, 1, -1);
  numBytes += cVar_init_f(&cVar_rNF79CL7, 0.0f);
  numBytes += cSlice_init(&cSlice_rS7mCTJj, 1, -1);
  numBytes += cVar_init_f(&cVar_NdVHtBcs, 0.313f);
  numBytes += cBinop_init(&cBinop_boSCMrB2, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_T7EBcG1b, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_RjiL4FIV, 0.0f);
  numBytes += cVar_init_f(&cVar_PghDLKdM, 1337.0f);
  numBytes += cVar_init_f(&cVar_y8EhCli1, 0.3f);
  numBytes += cBinop_init(&cBinop_iIVB2FiY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Og5FZMCl, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lUXsE1vQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YL3EYcp6, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_eUUfcVrn, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_93ksQO2h, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_FoDbPJ17, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_scjTbsJP, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_1QLDgCXn, 0.0f);
  numBytes += cVar_init_f(&cVar_xDl3xNVo, 1337.0f);
  numBytes += cVar_init_f(&cVar_DiRAn7Fe, 0.313f);
  numBytes += cBinop_init(&cBinop_K7O7r4cr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_YCrlYC0Q, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bMR794Iq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_WsXpdKLr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_E8P6soqZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Zob6arI0, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_iIOvTDEO, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_Ctu069Gc, 0.0f);
  numBytes += cVar_init_f(&cVar_XGjv7Ckc, 1037.0f);
  numBytes += cVar_init_f(&cVar_YwJ7t0Kc, 0.4f);
  numBytes += cBinop_init(&cBinop_QIpuN38m, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EDWTUekU, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ZkOPTdO3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_0XOmaNcQ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jN7KFh8u, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_qp3GGFqS, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_3WzIuWuY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BurItLyE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l8fHoiTF, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JQYK1JEp, 5705.6f);
  numBytes += cVar_init_f(&cVar_CIxvh0kQ, 313.3f);
  numBytes += cBinop_init(&cBinop_cE1phrK6, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_yq95Kc4Z, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_es3h5HPz, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_3Q::~Heavy_WSTD_3Q() {
  // nothing to free
}

HvTable *Heavy_WSTD_3Q::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_3Q::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZTh4Xi6o_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_uOrms6QN_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pn0KeOaP_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7cLiOR54_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ztQKGfWL_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9aGm8ix4_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZFdViKOZ_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PUeLZBhv_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R4ILd527_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Z0wnaUYG_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_TzHdwvGg_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7eUIoCd7_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZhRsAVrj_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CnuHveKW_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QsckhbpR_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JPYfLtGj_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_n8zMVUzu_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mTfbEyLU_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eeGgnpuB_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_KnwVdMJR_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Epu2GpzV_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WLJrKhzg_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4HnKR9eN_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_tIcOo80G_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cqhAUHVp_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iowdBzeS_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z0U6KJ5i_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_1TOqqhdW_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_RomVcN9E_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Re0s4gjW_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WpS5hsq4_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_68EiZkHo_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sqRcNKIK_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_3Q::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_3Q::cVar_LGXjhneP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_88IM9CrB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_5g5MTH2d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NCd0dEPf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_L9GZBib5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fwRtVHjo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Bj0VfxwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6haLAG35_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7X27LRrc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KYk95mLX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Uxmui9W4_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_0i9qxNvj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Oci2bq6w, 0, m, &cSlice_Oci2bq6w_sendMessage);
      break;
    }
    default: {
      cSwitchcase_HOQpaGpY_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_Oci2bq6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ieh9YMaK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ieh9YMaK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_cAuVvKQw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ieh9YMaK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ieh9YMaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZFdViKOZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_MFNUWxTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_sSlkirw1_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_PbaB51Kw, 0, m, &cIf_PbaB51Kw_sendMessage);
}

void Heavy_WSTD_3Q::cIf_PbaB51Kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_d3am4Zqv_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_vbloet2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_N50FGvEL_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_jSApNqsS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_Nu21tgQO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_g03WmxFo, HV_BINOP_POW, 0, m, &cBinop_g03WmxFo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_g03WmxFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HznVURQQ, 0, m, &cIf_HznVURQQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OLftARpX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_FL8HO5hM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Itiu7lEr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_X8ORI05Y_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FjbydUUD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbloet2a, 0, m, &cIf_vbloet2a_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_X8ORI05Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbloet2a, 1, m, &cIf_vbloet2a_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_jSApNqsS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_OLftARpX_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_N50FGvEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HznVURQQ, 0, m, &cIf_HznVURQQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_FL8HO5hM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g03WmxFo, HV_BINOP_POW, 1, m, &cBinop_g03WmxFo_sendMessage);
  cMsg_Nu21tgQO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_HznVURQQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_GnXgd6sr, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_sSlkirw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_PbaB51Kw, 1, m, &cIf_PbaB51Kw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_d3am4Zqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eTx8uQO1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_eTx8uQO1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2kUmddfC, HV_BINOP_EQ, 1, m, &cBinop_2kUmddfC_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_NI5mUzFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_QKPNEN9u, HV_BINOP_ADD, 0, m, &cBinop_QKPNEN9u_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QKPNEN9u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Itiu7lEr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FjbydUUD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eTx8uQO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HznVURQQ, 1, m, &cIf_HznVURQQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2kUmddfC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EYBaaizm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_EYBaaizm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_GnXgd6sr, m);
}

void Heavy_WSTD_3Q::cCast_V6M1Tatq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MFNUWxTN, 0, m, &cVar_MFNUWxTN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_YGyURxfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NI5mUzFw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_3xpjX3fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QKPNEN9u, HV_BINOP_ADD, 1, m, &cBinop_QKPNEN9u_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_eTx8uQO1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_eTx8uQO1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2kUmddfC, HV_BINOP_EQ, 0, m, &cBinop_2kUmddfC_sendMessage);
}

void Heavy_WSTD_3Q::cVar_LMHNFnwM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_rvFvLHDr_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_wlpFQM8c, 0, m, &cIf_wlpFQM8c_sendMessage);
}

void Heavy_WSTD_3Q::cIf_wlpFQM8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_wrBNR9xw_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_lL4uLZU3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_PBTX1Xup_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_GJUobnQq_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_sb1gbOuP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_VFlMIy0S, HV_BINOP_POW, 0, m, &cBinop_VFlMIy0S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_VFlMIy0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ozgzvXpr, 0, m, &cIf_ozgzvXpr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_61SRpTWz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Uccn0DKo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OBaz73Im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_MuM4CCyd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XchoyIHk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lL4uLZU3, 0, m, &cIf_lL4uLZU3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MuM4CCyd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lL4uLZU3, 1, m, &cIf_lL4uLZU3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GJUobnQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_61SRpTWz_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_PBTX1Xup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ozgzvXpr, 0, m, &cIf_ozgzvXpr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Uccn0DKo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VFlMIy0S, HV_BINOP_POW, 1, m, &cBinop_VFlMIy0S_sendMessage);
  cMsg_sb1gbOuP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_ozgzvXpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zlbJkJkr_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y1BBRYrb_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_kxXgSl24_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_rvFvLHDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wlpFQM8c, 1, m, &cIf_wlpFQM8c_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wrBNR9xw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_y40VKQ2E, HV_BINOP_GREATER_THAN, 1, m, &cBinop_y40VKQ2E_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ApexT5V, HV_BINOP_EQ, 1, m, &cBinop_7ApexT5V_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_OHXG7V3L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WDMKD9EM, HV_BINOP_ADD, 0, m, &cBinop_WDMKD9EM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WDMKD9EM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OBaz73Im_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XchoyIHk_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_y40VKQ2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ozgzvXpr, 1, m, &cIf_ozgzvXpr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_7ApexT5V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LXwna7Ys_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_LXwna7Ys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_zlbJkJkr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_y1BBRYrb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_kxXgSl24_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8oaNItRo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LMHNFnwM, 0, m, &cVar_LMHNFnwM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ddKxq7GU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OHXG7V3L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_u9YFHbAJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WDMKD9EM, HV_BINOP_ADD, 1, m, &cBinop_WDMKD9EM_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_y40VKQ2E, HV_BINOP_GREATER_THAN, 0, m, &cBinop_y40VKQ2E_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_7ApexT5V, HV_BINOP_EQ, 0, m, &cBinop_7ApexT5V_sendMessage);
}

void Heavy_WSTD_3Q::cVar_yWyLQVcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DSBbcGtI_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_b9S9gUPo, 0, m, &cIf_b9S9gUPo_sendMessage);
}

void Heavy_WSTD_3Q::cIf_b9S9gUPo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_3risyPMs_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_47FIPqtC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_xbhRWnaJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_Bxoi9cFu_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_V9kiU7Lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_WefBefpA, HV_BINOP_POW, 0, m, &cBinop_WefBefpA_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WefBefpA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HoYsaPOn, 0, m, &cIf_HoYsaPOn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_t6F86zCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_aldxSRkx_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AoYts7gF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_5IyAjkqz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_JNLx4xYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_47FIPqtC, 0, m, &cIf_47FIPqtC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5IyAjkqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_47FIPqtC, 1, m, &cIf_47FIPqtC_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Bxoi9cFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_t6F86zCJ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_xbhRWnaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_HoYsaPOn, 0, m, &cIf_HoYsaPOn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_aldxSRkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WefBefpA, HV_BINOP_POW, 1, m, &cBinop_WefBefpA_sendMessage);
  cMsg_V9kiU7Lh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_HoYsaPOn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_h9F5UT06, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_DSBbcGtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_b9S9gUPo, 1, m, &cIf_b9S9gUPo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3risyPMs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_42U5cGc1, HV_BINOP_GREATER_THAN, 1, m, &cBinop_42U5cGc1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8IOdtA5O, HV_BINOP_EQ, 1, m, &cBinop_8IOdtA5O_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_hBJuAFVT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_5DjfJHE6, HV_BINOP_ADD, 0, m, &cBinop_5DjfJHE6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5DjfJHE6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AoYts7gF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JNLx4xYc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_42U5cGc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HoYsaPOn, 1, m, &cIf_HoYsaPOn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8IOdtA5O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Srk2vnag_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Srk2vnag_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_h9F5UT06, m);
}

void Heavy_WSTD_3Q::cCast_l9zkJAz0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5DjfJHE6, HV_BINOP_ADD, 1, m, &cBinop_5DjfJHE6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_42U5cGc1, HV_BINOP_GREATER_THAN, 0, m, &cBinop_42U5cGc1_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8IOdtA5O, HV_BINOP_EQ, 0, m, &cBinop_8IOdtA5O_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Al3RWN4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yWyLQVcm, 0, m, &cVar_yWyLQVcm_sendMessage);
}

void Heavy_WSTD_3Q::cCast_BAGX6hrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hBJuAFVT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_Ekl0pJvI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_LT35FONL, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_YDR9wsIr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GPKKuYP9, 0, m, &cSlice_GPKKuYP9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_jSzqSLOG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_GPKKuYP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iIXgxAqF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iIXgxAqF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_sYqsyGXp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iIXgxAqF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_iIXgxAqF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ztQKGfWL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_jSzqSLOG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mMt8JWEd, 0, m, &cSlice_mMt8JWEd_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0i9qxNvj_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_mMt8JWEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_C8H4OFZQ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_C8H4OFZQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_FkbAUZup_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C8H4OFZQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_C8H4OFZQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R4ILd527_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_HOQpaGpY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vVDqpwxE, 0, m, &cSlice_vVDqpwxE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_3DjmfQPN_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_vVDqpwxE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_StJLUfgK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_StJLUfgK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_TE3Upfy3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_StJLUfgK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_StJLUfgK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_9aGm8ix4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_3DjmfQPN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oDWWWLTC, 0, m, &cSlice_oDWWWLTC_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_oDWWWLTC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JORtfkIX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JORtfkIX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_aNDBono4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JORtfkIX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_JORtfkIX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_PUeLZBhv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_gczp4t6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_iHAWnjhd, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_YI8vD9Pm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v9q9Nvkl, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_rPpVm4wZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Gq8kq6bj, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_yKdXOKsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_qmEGzyOo, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_0uN6TtXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1oazJ2JW, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_XLLUMBVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_EP8QXCV4_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_EP8QXCV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u5S2Tx1E, HV_BINOP_DIVIDE, 1, m, &cBinop_u5S2Tx1E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_H3QgnHtS_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_fCRIMZuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Lk8kVwAb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_kG2cCaY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_fCRIMZuV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Lk8kVwAb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_u5S2Tx1E, HV_BINOP_DIVIDE, 0, m, &cBinop_u5S2Tx1E_sendMessage);
}

void Heavy_WSTD_3Q::cCast_H3QgnHtS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kG2cCaY6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_u5S2Tx1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O0cffu3W, HV_BINOP_MULTIPLY, 1, m, &cBinop_O0cffu3W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_O0cffu3W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tm2oaWTz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yFgi1vV2_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_OLoBqgfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bWYDv5UV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_JnUTFYca_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0FcE35Fc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_2meQBlLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_2PjyOsoU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2PjyOsoU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_O0cffu3W, HV_BINOP_MULTIPLY, 0, m, &cBinop_O0cffu3W_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HDgxjUdF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_pdPCktbK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pdPCktbK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K3gJ2MZ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_a8L3xy4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mNQjYlFf, 1, m, &cVar_mNQjYlFf_sendMessage);
}

void Heavy_WSTD_3Q::cVar_mNQjYlFf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q0vBlk51_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_0ksGXp4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4hutjTPH, HV_BINOP_MULTIPLY, 1, m, &cBinop_4hutjTPH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UnfX4mIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0ksGXp4g_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OhmSgG8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_zb6UJeK5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zb6UJeK5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MXCepxxr, HV_BINOP_MULTIPLY, 1, m, &cBinop_MXCepxxr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xpkX2kJt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LEFqfmqW, HV_BINOP_MULTIPLY, 1, m, &cBinop_LEFqfmqW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_fwDCPCzd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xpkX2kJt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9pNBDArR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HKSx4J6u, HV_BINOP_MULTIPLY, 1, m, &cBinop_HKSx4J6u_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_lxORPxHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Rgfz959q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Rgfz959q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DlHuwtHB, HV_BINOP_MULTIPLY, 1, m, &cBinop_DlHuwtHB_sendMessage);
}

void Heavy_WSTD_3Q::cVar_vBwkg1DG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TBoczRwF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_2meQBlLv_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bFviw2Ks_sendMessage);
}

void Heavy_WSTD_3Q::cVar_oWhd69N4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_HDgxjUdF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Tm2oaWTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_OLoBqgfd_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yFgi1vV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_JnUTFYca_sendMessage);
}

void Heavy_WSTD_3Q::cSend_bWYDv5UV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7eUIoCd7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_0FcE35Fc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_TzHdwvGg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_vFToja05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Z0wnaUYG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_K3gJ2MZ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bDi4Z0IG_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_bDi4Z0IG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d7CUZJkT, HV_BINOP_MULTIPLY, 1, m, &cBinop_d7CUZJkT_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_d7CUZJkT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JyX7TJqK_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JyX7TJqK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vFToja05_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_Q0vBlk51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_as4EJaQo_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_as4EJaQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KNSkmC8p_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LLckCzsN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yKs1HyD9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DdABQp91_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7bRT82nM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n8dtzb7M_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4hutjTPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gczp4t6b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MXCepxxr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YI8vD9Pm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_LEFqfmqW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rPpVm4wZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_HKSx4J6u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yKdXOKsb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_DlHuwtHB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0uN6TtXE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_GLwL7ijM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oWhd69N4, 1, m, &cVar_oWhd69N4_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XiWyqJ46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vBwkg1DG, 0, m, &cVar_vBwkg1DG_sendMessage);
}

void Heavy_WSTD_3Q::cCast_n8dtzb7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4hutjTPH, HV_BINOP_MULTIPLY, 0, m, &cBinop_4hutjTPH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yKs1HyD9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HKSx4J6u, HV_BINOP_MULTIPLY, 0, m, &cBinop_HKSx4J6u_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7bRT82nM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MXCepxxr, HV_BINOP_MULTIPLY, 0, m, &cBinop_MXCepxxr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_LLckCzsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DlHuwtHB, HV_BINOP_MULTIPLY, 0, m, &cBinop_DlHuwtHB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DdABQp91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LEFqfmqW, HV_BINOP_MULTIPLY, 0, m, &cBinop_LEFqfmqW_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KNSkmC8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_bFviw2Ks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mNQjYlFf, 0, m, &cVar_mNQjYlFf_sendMessage);
}

void Heavy_WSTD_3Q::cCast_TBoczRwF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oWhd69N4, 0, m, &cVar_oWhd69N4_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_9PkYpYvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_eR7ZcX6W, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Ni91pIWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EppcuUID, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_yxux7teS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wGcy1KPF, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ol5Wuoj8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Yhy2wQ9Y, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_dyAsYvi2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hLeO5Ghl_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_hLeO5Ghl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BqugSVdC, HV_BINOP_DIVIDE, 1, m, &cBinop_BqugSVdC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_C8y571A0_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_GkmSJKUj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_8pH0knpa_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_SjiTMk7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_GkmSJKUj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8pH0knpa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BqugSVdC, HV_BINOP_DIVIDE, 0, m, &cBinop_BqugSVdC_sendMessage);
}

void Heavy_WSTD_3Q::cCast_C8y571A0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SjiTMk7m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_BqugSVdC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ARyFzBsy, HV_BINOP_MULTIPLY, 1, m, &cBinop_ARyFzBsy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ARyFzBsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FHuMxFWH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_25n3BLof_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_igtN67Xo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nxLelBY2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_SorNKbVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ZOzV51un_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_kGnhh8ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Zysghgua_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Zysghgua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ARyFzBsy, HV_BINOP_MULTIPLY, 0, m, &cBinop_ARyFzBsy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_eVcG6C95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_b5whqJsZ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_b5whqJsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HFEhOe5I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_tyhhezCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aQld2cTH, HV_BINOP_MULTIPLY, 1, m, &cBinop_aQld2cTH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8N2fbHkN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2dCk7T7j, 1, m, &cVar_2dCk7T7j_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_WERiqjkE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MeVkSNgU, HV_BINOP_MULTIPLY, 1, m, &cBinop_MeVkSNgU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_hjZbtsYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_r3aZKZZp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_r3aZKZZp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FhUGgLni, HV_BINOP_MULTIPLY, 1, m, &cBinop_FhUGgLni_sendMessage);
}

void Heavy_WSTD_3Q::cVar_2dCk7T7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wfhNMe6V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Eag805SN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2ccOVu0p_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_kGnhh8ls_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_715RQcOq_sendMessage);
}

void Heavy_WSTD_3Q::cVar_w4XItnEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_eVcG6C95_sendMessage);
}

void Heavy_WSTD_3Q::cCast_25n3BLof_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_SorNKbVN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FHuMxFWH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_igtN67Xo_sendMessage);
}

void Heavy_WSTD_3Q::cSend_nxLelBY2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_QsckhbpR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_ZOzV51un_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CnuHveKW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_lSg880Mg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ZhRsAVrj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_HFEhOe5I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_GsbYaYFw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_GsbYaYFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HcQH5qDM, HV_BINOP_MULTIPLY, 1, m, &cBinop_HcQH5qDM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_HcQH5qDM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_pxgV4uHR_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pxgV4uHR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lSg880Mg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_wfhNMe6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oKgHss9D_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_oKgHss9D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nS2b7Fey_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vzx3wpfj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tikVf372_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_f43oLVrt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9AqJmsiD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9PkYpYvh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_aQld2cTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ni91pIWN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MeVkSNgU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yxux7teS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FhUGgLni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ol5Wuoj8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_mr8nCAHj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w4XItnEv, 1, m, &cVar_w4XItnEv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_yPANtIgY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Eag805SN, 0, m, &cVar_Eag805SN_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2ccOVu0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_w4XItnEv, 0, m, &cVar_w4XItnEv_sendMessage);
}

void Heavy_WSTD_3Q::cCast_715RQcOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2dCk7T7j, 0, m, &cVar_2dCk7T7j_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tikVf372_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aQld2cTH, HV_BINOP_MULTIPLY, 0, m, &cBinop_aQld2cTH_sendMessage);
}

void Heavy_WSTD_3Q::cCast_vzx3wpfj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MeVkSNgU, HV_BINOP_MULTIPLY, 0, m, &cBinop_MeVkSNgU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_f43oLVrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9AqJmsiD, HV_BINOP_MULTIPLY, 0, m, &cBinop_9AqJmsiD_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nS2b7Fey_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FhUGgLni, HV_BINOP_MULTIPLY, 0, m, &cBinop_FhUGgLni_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_tGiLA0Iy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PfN9zJXM, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_QrKB2lnJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ywm8N8Ug, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_b1eXFIl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hpyNO9jx, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_10xAvRpN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ULzSpYVr, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_Y6tm27sh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KzYakTuc, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_ojo5CBXa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_17HH795e_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_17HH795e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ob9kWn2z, HV_BINOP_DIVIDE, 1, m, &cBinop_Ob9kWn2z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KfmUakTz_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_DtX7ZjT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_KX2GWfJn_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_1WWdih8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_DtX7ZjT7_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KX2GWfJn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ob9kWn2z, HV_BINOP_DIVIDE, 0, m, &cBinop_Ob9kWn2z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KfmUakTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1WWdih8g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Ob9kWn2z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cz6oN4dX, HV_BINOP_MULTIPLY, 1, m, &cBinop_cz6oN4dX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cz6oN4dX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aJRgSblb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GECSNKhw_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_R94MAZJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Tx8phICR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_wwHCkwf6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uIdNhyo9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_K0ILDjQy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_PMqWv4EF_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_PMqWv4EF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cz6oN4dX, HV_BINOP_MULTIPLY, 0, m, &cBinop_cz6oN4dX_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_3DPyW2p6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_MvQMZbiV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MvQMZbiV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MVazLbqu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_UvoUfzk7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qewGKoJB, HV_BINOP_MULTIPLY, 1, m, &cBinop_qewGKoJB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_n9MvuERz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ps6neYiq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ps6neYiq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UvoUfzk7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_0ceVDqXw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yzO3fWm5_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yzO3fWm5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wNSOB0J0, HV_BINOP_MULTIPLY, 1, m, &cBinop_wNSOB0J0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1u2XtI9Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fOXcc63n, HV_BINOP_MULTIPLY, 1, m, &cBinop_fOXcc63n_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_rv63AVXc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_zaTaVJ9j_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zaTaVJ9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_1u2XtI9Q_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0RDI5WV5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j6Vk5qis, 1, m, &cVar_j6Vk5qis_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_OJI3ARSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Z7awi9Z, HV_BINOP_MULTIPLY, 1, m, &cBinop_4Z7awi9Z_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_BfXe7oXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ywqQmaRP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ywqQmaRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ufzdYQKU, HV_BINOP_MULTIPLY, 1, m, &cBinop_ufzdYQKU_sendMessage);
}

void Heavy_WSTD_3Q::cVar_j6Vk5qis_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SnFOZLW3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_CjeWJXy9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qoBUMsZU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_K0ILDjQy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FSoUXdQ3_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Tz8HD57E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_3DPyW2p6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aJRgSblb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_R94MAZJ6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GECSNKhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_wwHCkwf6_sendMessage);
}

void Heavy_WSTD_3Q::cSend_Tx8phICR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mTfbEyLU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_uIdNhyo9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_n8zMVUzu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_GRYZvC5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JPYfLtGj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_MVazLbqu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_A8jFYBC8_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_A8jFYBC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tt9f8ncp, HV_BINOP_MULTIPLY, 1, m, &cBinop_tt9f8ncp_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_tt9f8ncp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_5wb1fobb_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_5wb1fobb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GRYZvC5Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_SnFOZLW3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_x0Ocqt7C_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_x0Ocqt7C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8kZ7d33P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oyk8XUa0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jMiEQjeh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_frvcancZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CxvfkpFN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LMB0GpGf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_qewGKoJB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tGiLA0Iy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_wNSOB0J0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QrKB2lnJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_fOXcc63n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_b1eXFIl0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_4Z7awi9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_10xAvRpN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ufzdYQKU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Y6tm27sh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_yGDPbZok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CjeWJXy9, 0, m, &cVar_CjeWJXy9_sendMessage);
}

void Heavy_WSTD_3Q::cCast_IKjNumpf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tz8HD57E, 1, m, &cVar_Tz8HD57E_sendMessage);
}

void Heavy_WSTD_3Q::cCast_jMiEQjeh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Z7awi9Z, HV_BINOP_MULTIPLY, 0, m, &cBinop_4Z7awi9Z_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CxvfkpFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_wNSOB0J0, HV_BINOP_MULTIPLY, 0, m, &cBinop_wNSOB0J0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oyk8XUa0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ufzdYQKU, HV_BINOP_MULTIPLY, 0, m, &cBinop_ufzdYQKU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_frvcancZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fOXcc63n, HV_BINOP_MULTIPLY, 0, m, &cBinop_fOXcc63n_sendMessage);
}

void Heavy_WSTD_3Q::cCast_8kZ7d33P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_LMB0GpGf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qewGKoJB, HV_BINOP_MULTIPLY, 0, m, &cBinop_qewGKoJB_sendMessage);
}

void Heavy_WSTD_3Q::cCast_FSoUXdQ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_j6Vk5qis, 0, m, &cVar_j6Vk5qis_sendMessage);
}

void Heavy_WSTD_3Q::cCast_qoBUMsZU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tz8HD57E, 0, m, &cVar_Tz8HD57E_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_zlbJkJkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ekl0pJvI, 1, m, &cIf_Ekl0pJvI_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_L0vpaW3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_LT35FONL, m);
}

void Heavy_WSTD_3Q::cBinop_y1BBRYrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L0vpaW3h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_kxXgSl24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ekl0pJvI, 0, m, &cIf_Ekl0pJvI_sendMessage);
}

void Heavy_WSTD_3Q::cSwitchcase_WTx3KXlI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_yEMoWvfz, 0, m, &cSlice_yEMoWvfz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ThylinR7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_yEMoWvfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OYGbpLf8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OYGbpLf8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_zoksfoLq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OYGbpLf8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_OYGbpLf8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Epu2GpzV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_NsYu8acF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_PVof9U7N_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_BT6hZWNI, 0, m, &cIf_BT6hZWNI_sendMessage);
}

void Heavy_WSTD_3Q::cIf_BT6hZWNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_yyLEIXPS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_1HGJDVzq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_w8yHFTuC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_08XEuZ1V_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_IdxylQwP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_0XS44ZYh, HV_BINOP_POW, 0, m, &cBinop_0XS44ZYh_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0XS44ZYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MvOIwmSc, 0, m, &cIf_MvOIwmSc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_RHznc6I2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_pPXktfzY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_aSwd91Ek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1HGJDVzq, 0, m, &cIf_1HGJDVzq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_QHZ2wJoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_DgNNHFjg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_DgNNHFjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1HGJDVzq, 1, m, &cIf_1HGJDVzq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_08XEuZ1V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_RHznc6I2_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_w8yHFTuC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_MvOIwmSc, 0, m, &cIf_MvOIwmSc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_pPXktfzY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0XS44ZYh, HV_BINOP_POW, 1, m, &cBinop_0XS44ZYh_sendMessage);
  cMsg_IdxylQwP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_MvOIwmSc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_3WzIuWuY, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_PVof9U7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BT6hZWNI, 1, m, &cIf_BT6hZWNI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yyLEIXPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_f2hC6Eyq, HV_BINOP_GREATER_THAN, 1, m, &cBinop_f2hC6Eyq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y35BAjMB, HV_BINOP_EQ, 1, m, &cBinop_Y35BAjMB_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Ir1Kqqr9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2hnJtD9o, HV_BINOP_ADD, 0, m, &cBinop_2hnJtD9o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2hnJtD9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QHZ2wJoh_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aSwd91Ek_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_f2hC6Eyq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MvOIwmSc, 1, m, &cIf_MvOIwmSc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Y35BAjMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_htxZgrVO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_htxZgrVO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_3WzIuWuY, m);
}

void Heavy_WSTD_3Q::cCast_9NMUKKgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NsYu8acF, 0, m, &cVar_NsYu8acF_sendMessage);
}

void Heavy_WSTD_3Q::cCast_X610rijU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ir1Kqqr9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_1nnFBetS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_2hnJtD9o, HV_BINOP_ADD, 1, m, &cBinop_2hnJtD9o_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_f2hC6Eyq, HV_BINOP_GREATER_THAN, 0, m, &cBinop_f2hC6Eyq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Y35BAjMB, HV_BINOP_EQ, 0, m, &cBinop_Y35BAjMB_sendMessage);
}

void Heavy_WSTD_3Q::cVar_oB7tcJ19_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_0YXph04X_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_jHi7DsL6, 0, m, &cIf_jHi7DsL6_sendMessage);
}

void Heavy_WSTD_3Q::cIf_jHi7DsL6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_t5fVf6Ij_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_SisU4XzM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_pGKyWQIu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_UaifJNKr_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_zpE7HXne_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_au0gAn56, HV_BINOP_POW, 0, m, &cBinop_au0gAn56_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_au0gAn56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0jNen0pd, 0, m, &cIf_0jNen0pd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_BaV1E6D7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_SpxUgiLw_sendMessage);
}

void Heavy_WSTD_3Q::cCast_UGnKFY2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SisU4XzM, 0, m, &cIf_SisU4XzM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RSV0cyTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_JT1vzZUW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_JT1vzZUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SisU4XzM, 1, m, &cIf_SisU4XzM_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_UaifJNKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_BaV1E6D7_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_pGKyWQIu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_0jNen0pd, 0, m, &cIf_0jNen0pd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SpxUgiLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_au0gAn56, HV_BINOP_POW, 1, m, &cBinop_au0gAn56_sendMessage);
  cMsg_zpE7HXne_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_0jNen0pd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_svyAIFcs_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bgj2NxPx_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Pssal8Sn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_0YXph04X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jHi7DsL6, 1, m, &cIf_jHi7DsL6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_t5fVf6Ij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_13KxfUAB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_13KxfUAB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2BOsQ9qa, HV_BINOP_EQ, 1, m, &cBinop_2BOsQ9qa_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_8sXpCqOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_KokH4pqt, HV_BINOP_ADD, 0, m, &cBinop_KokH4pqt_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KokH4pqt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RSV0cyTW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UGnKFY2y_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_13KxfUAB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0jNen0pd, 1, m, &cIf_0jNen0pd_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2BOsQ9qa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_atd6vfH4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_atd6vfH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_svyAIFcs_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_bgj2NxPx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Pssal8Sn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hSvhZ5dO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KokH4pqt, HV_BINOP_ADD, 1, m, &cBinop_KokH4pqt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_13KxfUAB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_13KxfUAB_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_2BOsQ9qa, HV_BINOP_EQ, 0, m, &cBinop_2BOsQ9qa_sendMessage);
}

void Heavy_WSTD_3Q::cCast_mmnYDDww_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oB7tcJ19, 0, m, &cVar_oB7tcJ19_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xX3pbldQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8sXpCqOB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_Tv3krW75_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_7VfK3jcE_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_0Xk2V2y1, 0, m, &cIf_0Xk2V2y1_sendMessage);
}

void Heavy_WSTD_3Q::cIf_0Xk2V2y1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9IAXVfBc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cIf_dbC7btRl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_qAuFNGsB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_b3Mnqn5g_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cMsg_ktSoCtqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_hX2xMdKj, HV_BINOP_POW, 0, m, &cBinop_hX2xMdKj_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_hX2xMdKj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DRw49dwD, 0, m, &cIf_DRw49dwD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8KzQYPoh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_9nynMn8N_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NHgg48Hu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dbC7btRl, 0, m, &cIf_dbC7btRl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_XskYBloK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_8s3pMNn0_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8s3pMNn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dbC7btRl, 1, m, &cIf_dbC7btRl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_b3Mnqn5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_8KzQYPoh_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_qAuFNGsB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_DRw49dwD, 0, m, &cIf_DRw49dwD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9nynMn8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hX2xMdKj, HV_BINOP_POW, 1, m, &cBinop_hX2xMdKj_sendMessage);
  cMsg_ktSoCtqb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cIf_DRw49dwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_l8fHoiTF, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cBinop_7VfK3jcE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0Xk2V2y1, 1, m, &cIf_0Xk2V2y1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_9IAXVfBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_1NJe2IKg, HV_BINOP_GREATER_THAN, 1, m, &cBinop_1NJe2IKg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_m7rzW7vb, HV_BINOP_EQ, 1, m, &cBinop_m7rzW7vb_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_aKgmbSKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_n2qG79Yq, HV_BINOP_ADD, 0, m, &cBinop_n2qG79Yq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_n2qG79Yq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XskYBloK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NHgg48Hu_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_1NJe2IKg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DRw49dwD, 1, m, &cIf_DRw49dwD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_m7rzW7vb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zFrvDH4y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_zFrvDH4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_l8fHoiTF, m);
}

void Heavy_WSTD_3Q::cCast_UkS2Mx42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aKgmbSKD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_nyajlf0t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n2qG79Yq, HV_BINOP_ADD, 1, m, &cBinop_n2qG79Yq_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_1NJe2IKg, HV_BINOP_GREATER_THAN, 0, m, &cBinop_1NJe2IKg_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_m7rzW7vb, HV_BINOP_EQ, 0, m, &cBinop_m7rzW7vb_sendMessage);
}

void Heavy_WSTD_3Q::cCast_MKRaMSPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Tv3krW75, 0, m, &cVar_Tv3krW75_sendMessage);
}

void Heavy_WSTD_3Q::cIf_K7kYkfCV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_BurItLyE, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cSwitchcase_Rzaip1iC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_QsnD6i4r, 0, m, &cSlice_QsnD6i4r_sendMessage);
      break;
    }
    default: {
      cSwitchcase_D4PNvRwv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_QsnD6i4r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Q6VJ5g4g_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Q6VJ5g4g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_lCYd6rv9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Q6VJ5g4g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Q6VJ5g4g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eeGgnpuB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_D4PNvRwv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6v364kQE, 0, m, &cSlice_6v364kQE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WTx3KXlI_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_6v364kQE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_R5wLrbAn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_R5wLrbAn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_qLK92Rrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_R5wLrbAn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_R5wLrbAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4HnKR9eN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_ThylinR7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_X69u879E, 0, m, &cSlice_X69u879E_sendMessage);
      break;
    }
    default: {
      cSwitchcase_v3613g7s_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_X69u879E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gmmtITMd_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gmmtITMd_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_rNF79CL7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gmmtITMd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_gmmtITMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_KnwVdMJR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSwitchcase_v3613g7s_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rS7mCTJj, 0, m, &cSlice_rS7mCTJj_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_3Q::cSlice_rS7mCTJj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sdNbI0b3_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sdNbI0b3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_3Q::cVar_NdVHtBcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sdNbI0b3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_sdNbI0b3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WLJrKhzg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_NCHzJaxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hFefh3BO, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_LdyUVdDz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yPtnnMvF, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_dK0BLpek_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_DKt35oPf, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_nxwcJxcL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ppc3quhn, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_bGYtWf5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vkeTA81Q, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_BtEfiHfM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_SAEVFJog_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_SAEVFJog_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_boSCMrB2, HV_BINOP_DIVIDE, 1, m, &cBinop_boSCMrB2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oMIqFs0Q_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_HTZwc2o6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Rrhv0UXM_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Suo9fre2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_HTZwc2o6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Rrhv0UXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_boSCMrB2, HV_BINOP_DIVIDE, 0, m, &cBinop_boSCMrB2_sendMessage);
}

void Heavy_WSTD_3Q::cCast_oMIqFs0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Suo9fre2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_boSCMrB2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T7EBcG1b, HV_BINOP_MULTIPLY, 1, m, &cBinop_T7EBcG1b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_T7EBcG1b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GJiAwy9g_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xMIzOY1n_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_U8ZN6OAV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_vCgjJ8uQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_3Vj7NhPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_y7d2FrgL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Mka4kipj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_wyYwV4l4_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wyYwV4l4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_T7EBcG1b, HV_BINOP_MULTIPLY, 0, m, &cBinop_T7EBcG1b_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Oh9mMqZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_risFYeVW_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_risFYeVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QcljJxtY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_3aalGI24_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RjiL4FIV, 1, m, &cVar_RjiL4FIV_sendMessage);
}

void Heavy_WSTD_3Q::cVar_RjiL4FIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tbhKtUjn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MuBb5IxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Og5FZMCl, HV_BINOP_MULTIPLY, 1, m, &cBinop_Og5FZMCl_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_l8kAavAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_MuBb5IxJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_36fxeYz9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_4KBh9ojg_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_4KBh9ojg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lUXsE1vQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_lUXsE1vQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZmRPEq3e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YL3EYcp6, HV_BINOP_MULTIPLY, 1, m, &cBinop_YL3EYcp6_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_6799I08L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZmRPEq3e_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_KqoRWKV7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eUUfcVrn, HV_BINOP_MULTIPLY, 1, m, &cBinop_eUUfcVrn_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_SnS3HUlu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_B8GCaKwJ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_B8GCaKwJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_93ksQO2h, HV_BINOP_MULTIPLY, 1, m, &cBinop_93ksQO2h_sendMessage);
}

void Heavy_WSTD_3Q::cVar_PghDLKdM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tK3lNg1a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_Mka4kipj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DJ6CVTy8_sendMessage);
}

void Heavy_WSTD_3Q::cVar_y8EhCli1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Oh9mMqZr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_GJiAwy9g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_U8ZN6OAV_sendMessage);
}

void Heavy_WSTD_3Q::cCast_xMIzOY1n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_3Vj7NhPP_sendMessage);
}

void Heavy_WSTD_3Q::cSend_vCgjJ8uQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iowdBzeS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_y7d2FrgL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cqhAUHVp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_nZhdqPYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_tIcOo80G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_QcljJxtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_rfhq2M0o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_rfhq2M0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iIVB2FiY, HV_BINOP_MULTIPLY, 1, m, &cBinop_iIVB2FiY_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iIVB2FiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0xausIpD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_0xausIpD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nZhdqPYs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_tbhKtUjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_EcrnTdsE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EcrnTdsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2dGGExRD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dNnvUBfP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RKiYss8y_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Q6PUEpL5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZAQfSNEL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ch82K78o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Og5FZMCl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NCHzJaxi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_lUXsE1vQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LdyUVdDz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_YL3EYcp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dK0BLpek_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_eUUfcVrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nxwcJxcL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_93ksQO2h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bGYtWf5R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_iaM1aSN0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PghDLKdM, 0, m, &cVar_PghDLKdM_sendMessage);
}

void Heavy_WSTD_3Q::cCast_N6FIeToV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y8EhCli1, 1, m, &cVar_y8EhCli1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ZAQfSNEL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lUXsE1vQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_lUXsE1vQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_dNnvUBfP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_93ksQO2h, HV_BINOP_MULTIPLY, 0, m, &cBinop_93ksQO2h_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Q6PUEpL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YL3EYcp6, HV_BINOP_MULTIPLY, 0, m, &cBinop_YL3EYcp6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_2dGGExRD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_ch82K78o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Og5FZMCl, HV_BINOP_MULTIPLY, 0, m, &cBinop_Og5FZMCl_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RKiYss8y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_eUUfcVrn, HV_BINOP_MULTIPLY, 0, m, &cBinop_eUUfcVrn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tK3lNg1a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_y8EhCli1, 0, m, &cVar_y8EhCli1_sendMessage);
}

void Heavy_WSTD_3Q::cCast_DJ6CVTy8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_RjiL4FIV, 0, m, &cVar_RjiL4FIV_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_HeshWTw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_J8tltp85, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_zfLsR2Cj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CcCXTdn6, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_I8z5jLG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o4wkmNiL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_paPTeAEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uctpVg2V, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_EV98i8vH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_C3y6sTZL_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_C3y6sTZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FoDbPJ17, HV_BINOP_DIVIDE, 1, m, &cBinop_FoDbPJ17_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E6L6ciRr_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_TWpZTFe9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_CokUg3Lp_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_UzwoCcaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_TWpZTFe9_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_CokUg3Lp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FoDbPJ17, HV_BINOP_DIVIDE, 0, m, &cBinop_FoDbPJ17_sendMessage);
}

void Heavy_WSTD_3Q::cCast_E6L6ciRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UzwoCcaF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_FoDbPJ17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_scjTbsJP, HV_BINOP_MULTIPLY, 1, m, &cBinop_scjTbsJP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_scjTbsJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OMaw3yuz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tyNhQEv4_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_MwEdkuyl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_b2FCvSUp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_Ci17H1UY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cMjEnKAF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_MJFAQWnb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_80wdgHCf_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_80wdgHCf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_scjTbsJP, HV_BINOP_MULTIPLY, 0, m, &cBinop_scjTbsJP_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_wtUT1C2r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_gEkci10s_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gEkci10s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9tB2eHmU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_xYesSGj6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bMR794Iq, HV_BINOP_MULTIPLY, 1, m, &cBinop_bMR794Iq_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Fr5iFwue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1QLDgCXn, 1, m, &cVar_1QLDgCXn_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Rs1SktHX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WsXpdKLr, HV_BINOP_MULTIPLY, 1, m, &cBinop_WsXpdKLr_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_JRYwJMcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TID7HMZV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_TID7HMZV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E8P6soqZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_E8P6soqZ_sendMessage);
}

void Heavy_WSTD_3Q::cVar_1QLDgCXn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TMh35qSg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_xDl3xNVo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_THc1NrrP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_MJFAQWnb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Td4TIDO6_sendMessage);
}

void Heavy_WSTD_3Q::cVar_DiRAn7Fe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_wtUT1C2r_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tyNhQEv4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_Ci17H1UY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_OMaw3yuz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_MwEdkuyl_sendMessage);
}

void Heavy_WSTD_3Q::cSend_b2FCvSUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_RomVcN9E_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_cMjEnKAF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_1TOqqhdW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_C205HoBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_z0U6KJ5i_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_9tB2eHmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_xnzFZ511_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_xnzFZ511_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K7O7r4cr, HV_BINOP_MULTIPLY, 1, m, &cBinop_K7O7r4cr_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_K7O7r4cr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yteVCg4h_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yteVCg4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_C205HoBd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_TMh35qSg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_00rMYEdE_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_00rMYEdE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9K4GFJqn_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VDhPe24G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hSPjT28c_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_htBgNyOy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YCrlYC0Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HeshWTw4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_bMR794Iq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zfLsR2Cj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_WsXpdKLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I8z5jLG6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_E8P6soqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_paPTeAEy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_Nhwdeego_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DiRAn7Fe, 1, m, &cVar_DiRAn7Fe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9FW719np_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xDl3xNVo, 0, m, &cVar_xDl3xNVo_sendMessage);
}

void Heavy_WSTD_3Q::cCast_THc1NrrP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_DiRAn7Fe, 0, m, &cVar_DiRAn7Fe_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Td4TIDO6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1QLDgCXn, 0, m, &cVar_1QLDgCXn_sendMessage);
}

void Heavy_WSTD_3Q::cCast_hSPjT28c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bMR794Iq, HV_BINOP_MULTIPLY, 0, m, &cBinop_bMR794Iq_sendMessage);
}

void Heavy_WSTD_3Q::cCast_VDhPe24G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_WsXpdKLr, HV_BINOP_MULTIPLY, 0, m, &cBinop_WsXpdKLr_sendMessage);
}

void Heavy_WSTD_3Q::cCast_htBgNyOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YCrlYC0Q, HV_BINOP_MULTIPLY, 0, m, &cBinop_YCrlYC0Q_sendMessage);
}

void Heavy_WSTD_3Q::cCast_9K4GFJqn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_E8P6soqZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_E8P6soqZ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_rNbXFJbH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dCF53TD5, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_43mJk8WI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_m4Y6EUBk, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_pLe0b2Ue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QNMgRTPC, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_E0trfQcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8ZooiglC, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_dOqLQITM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OhoyiwcX, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_s8hkq9YP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_2l28zcGN_sendMessage);
}

void Heavy_WSTD_3Q::cSystem_2l28zcGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zob6arI0, HV_BINOP_DIVIDE, 1, m, &cBinop_Zob6arI0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AeUlrpEJ_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_11FctBLV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_E20h2L4X_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_XXyasYNZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_11FctBLV_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_E20h2L4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Zob6arI0, HV_BINOP_DIVIDE, 0, m, &cBinop_Zob6arI0_sendMessage);
}

void Heavy_WSTD_3Q::cCast_AeUlrpEJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XXyasYNZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Zob6arI0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iIOvTDEO, HV_BINOP_MULTIPLY, 1, m, &cBinop_iIOvTDEO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_iIOvTDEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NATbtMbj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tXYpj6Yu_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_k5iWIrkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Y2gLoynl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cUnop_xIlX3ALY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VYg8CffU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SX5ryDxD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Ls2yY01v_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Ls2yY01v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iIOvTDEO, HV_BINOP_MULTIPLY, 0, m, &cBinop_iIOvTDEO_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_SjzML7x7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_MT7n3HTH_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_MT7n3HTH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_W8lm1t0p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_SBpE34YZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EDWTUekU, HV_BINOP_MULTIPLY, 1, m, &cBinop_EDWTUekU_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_Q0lPu0hK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_lQG1Dz0S_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_lQG1Dz0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_SBpE34YZ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_CCr9o0bA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_YyIxYwCs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_YyIxYwCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZkOPTdO3, HV_BINOP_MULTIPLY, 1, m, &cBinop_ZkOPTdO3_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Qulj90ks_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0XOmaNcQ, HV_BINOP_MULTIPLY, 1, m, &cBinop_0XOmaNcQ_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_I4Ly0VUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_gXlQy4VI_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_gXlQy4VI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Qulj90ks_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_e6rpApYb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ctu069Gc, 1, m, &cVar_Ctu069Gc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_ZE8SjIts_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jN7KFh8u, HV_BINOP_MULTIPLY, 1, m, &cBinop_jN7KFh8u_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_EqllBlRF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_2nhxGxsD_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_2nhxGxsD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qp3GGFqS, HV_BINOP_MULTIPLY, 1, m, &cBinop_qp3GGFqS_sendMessage);
}

void Heavy_WSTD_3Q::cVar_Ctu069Gc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0Etyk6PC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cVar_XGjv7Ckc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EGGQgQDY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_SX5ryDxD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ASUMhaIg_sendMessage);
}

void Heavy_WSTD_3Q::cVar_YwJ7t0Kc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_SjzML7x7_sendMessage);
}

void Heavy_WSTD_3Q::cCast_tXYpj6Yu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_xIlX3ALY_sendMessage);
}

void Heavy_WSTD_3Q::cCast_NATbtMbj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_k5iWIrkh_sendMessage);
}

void Heavy_WSTD_3Q::cSend_Y2gLoynl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_68EiZkHo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_VYg8CffU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WpS5hsq4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cSend_Blwrnwyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Re0s4gjW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_W8lm1t0p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_uWt8Rroy_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_uWt8Rroy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QIpuN38m, HV_BINOP_MULTIPLY, 1, m, &cBinop_QIpuN38m_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_QIpuN38m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_yYzq8F5X_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yYzq8F5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Blwrnwyt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_0Etyk6PC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_dXb4GO0o_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_dXb4GO0o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uf3RJuBX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rbqFDDLF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RiDHmx5Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CKChnbop_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nTX4kp0i_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wo4CLwzw_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_EDWTUekU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rNbXFJbH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_ZkOPTdO3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_43mJk8WI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_0XOmaNcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pLe0b2Ue_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_jN7KFh8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E0trfQcj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_qp3GGFqS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dOqLQITM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cCast_WNUfsSqX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XGjv7Ckc, 0, m, &cVar_XGjv7Ckc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KSwM1w8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YwJ7t0Kc, 1, m, &cVar_YwJ7t0Kc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_nTX4kp0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZkOPTdO3, HV_BINOP_MULTIPLY, 0, m, &cBinop_ZkOPTdO3_sendMessage);
}

void Heavy_WSTD_3Q::cCast_rbqFDDLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_qp3GGFqS, HV_BINOP_MULTIPLY, 0, m, &cBinop_qp3GGFqS_sendMessage);
}

void Heavy_WSTD_3Q::cCast_CKChnbop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0XOmaNcQ, HV_BINOP_MULTIPLY, 0, m, &cBinop_0XOmaNcQ_sendMessage);
}

void Heavy_WSTD_3Q::cCast_uf3RJuBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_3Q::cCast_wo4CLwzw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EDWTUekU, HV_BINOP_MULTIPLY, 0, m, &cBinop_EDWTUekU_sendMessage);
}

void Heavy_WSTD_3Q::cCast_RiDHmx5Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jN7KFh8u, HV_BINOP_MULTIPLY, 0, m, &cBinop_jN7KFh8u_sendMessage);
}

void Heavy_WSTD_3Q::cCast_ASUMhaIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ctu069Gc, 0, m, &cVar_Ctu069Gc_sendMessage);
}

void Heavy_WSTD_3Q::cCast_EGGQgQDY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YwJ7t0Kc, 0, m, &cVar_YwJ7t0Kc_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_svyAIFcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K7kYkfCV, 1, m, &cIf_K7kYkfCV_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_LHL2hnlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_BurItLyE, m);
}

void Heavy_WSTD_3Q::cBinop_bgj2NxPx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LHL2hnlZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cBinop_Pssal8Sn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_K7kYkfCV, 0, m, &cIf_K7kYkfCV_sendMessage);
}

void Heavy_WSTD_3Q::cVar_JQYK1JEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yq95Kc4Z, HV_BINOP_DIVIDE, 0, m, &cBinop_yq95Kc4Z_sendMessage);
}

void Heavy_WSTD_3Q::cVar_CIxvh0kQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cE1phrK6, HV_BINOP_DIVIDE, 1, m, &cBinop_cE1phrK6_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yq95Kc4Z, HV_BINOP_DIVIDE, 1, m, &cBinop_yq95Kc4Z_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_ub5GZ4A1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_es3h5HPz, HV_BINOP_DIVIDE, 0, m, &cBinop_es3h5HPz_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_SrG2WaVN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_es3h5HPz, HV_BINOP_DIVIDE, 1, m, &cBinop_es3h5HPz_sendMessage);
}

void Heavy_WSTD_3Q::cCast_Uxmui9W4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_cE1phrK6, HV_BINOP_DIVIDE, 0, m, &cBinop_cE1phrK6_sendMessage);
}

void Heavy_WSTD_3Q::cCast_KYk95mLX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JQYK1JEp, 0, m, &cVar_JQYK1JEp_sendMessage);
}

void Heavy_WSTD_3Q::cCast_7X27LRrc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CIxvh0kQ, 0, m, &cVar_CIxvh0kQ_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_cE1phrK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_ub5GZ4A1_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_yq95Kc4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_SrG2WaVN_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_es3h5HPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_IWPgBiYw_sendMessage);
}

void Heavy_WSTD_3Q::cUnop_p8I7hwgs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_vJwJSr26_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_Cge3fS3m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_8UI2YmXU_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_IWPgBiYw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Cge3fS3m_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_8UI2YmXU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_p8I7hwgs_sendMessage);
}

void Heavy_WSTD_3Q::cBinop_vJwJSr26_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DUt6ymjh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cMsg_88IM9CrB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YDR9wsIr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Rzaip1iC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_NCd0dEPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YDR9wsIr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Rzaip1iC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_fwRtVHjo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YDR9wsIr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Rzaip1iC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_6haLAG35_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YDR9wsIr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Rzaip1iC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_DUt6ymjh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_YDR9wsIr_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_Rzaip1iC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_3Q::cMsg_1xe8x1Gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Bj0VfxwX, 0, m, &cVar_Bj0VfxwX_sendMessage);
}

void Heavy_WSTD_3Q::cMsg_XlagLmwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_LGXjhneP, 0, m, &cVar_LGXjhneP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5g5MTH2d, 0, m, &cVar_5g5MTH2d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_L9GZBib5, 0, m, &cVar_L9GZBib5_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZTh4Xi6o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_LGXjhneP, 0, m, &cVar_LGXjhneP_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_pn0KeOaP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5g5MTH2d, 0, m, &cVar_5g5MTH2d_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_uOrms6QN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_L9GZBib5, 0, m, &cVar_L9GZBib5_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZFdViKOZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Eag805SN, 0, m, &cVar_Eag805SN_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_PUeLZBhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mr8nCAHj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yPANtIgY_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ztQKGfWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V6M1Tatq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3xpjX3fn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YGyURxfK_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_9aGm8ix4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Al3RWN4j_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l9zkJAz0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BAGX6hrS_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_R4ILd527_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8oaNItRo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u9YFHbAJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ddKxq7GU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_sqRcNKIK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XLLUMBVI_sendMessage(_c, 0, m);
  cMsg_dyAsYvi2_sendMessage(_c, 0, m);
  cMsg_ojo5CBXa_sendMessage(_c, 0, m);
  cMsg_BtEfiHfM_sendMessage(_c, 0, m);
  cMsg_EV98i8vH_sendMessage(_c, 0, m);
  cMsg_s8hkq9YP_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_vBwkg1DG, 0, m, &cVar_vBwkg1DG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Eag805SN, 0, m, &cVar_Eag805SN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CjeWJXy9, 0, m, &cVar_CjeWJXy9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_PghDLKdM, 0, m, &cVar_PghDLKdM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_xDl3xNVo, 0, m, &cVar_xDl3xNVo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XGjv7Ckc, 0, m, &cVar_XGjv7Ckc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_cAuVvKQw, 0, m, &cVar_cAuVvKQw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MFNUWxTN, 0, m, &cVar_MFNUWxTN_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LMHNFnwM, 0, m, &cVar_LMHNFnwM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yWyLQVcm, 0, m, &cVar_yWyLQVcm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sYqsyGXp, 0, m, &cVar_sYqsyGXp_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FkbAUZup, 0, m, &cVar_FkbAUZup_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_TE3Upfy3, 0, m, &cVar_TE3Upfy3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aNDBono4, 0, m, &cVar_aNDBono4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zoksfoLq, 0, m, &cVar_zoksfoLq_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NsYu8acF, 0, m, &cVar_NsYu8acF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_oB7tcJ19, 0, m, &cVar_oB7tcJ19_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Tv3krW75, 0, m, &cVar_Tv3krW75_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_lCYd6rv9, 0, m, &cVar_lCYd6rv9_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_qLK92Rrn, 0, m, &cVar_qLK92Rrn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_rNF79CL7, 0, m, &cVar_rNF79CL7_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_NdVHtBcs, 0, m, &cVar_NdVHtBcs_sendMessage);
  cMsg_XlagLmwT_sendMessage(_c, 0, m);
  cMsg_1xe8x1Gf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_7eUIoCd7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_d7CUZJkT, HV_BINOP_MULTIPLY, 0, m, &cBinop_d7CUZJkT_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_TzHdwvGg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_UnfX4mIg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_OhmSgG8Y_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_fwDCPCzd_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_9pNBDArR_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Z0wnaUYG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_a8L3xy4b_sendMessage);
  cMsg_lxORPxHe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_QsckhbpR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HcQH5qDM, HV_BINOP_MULTIPLY, 0, m, &cBinop_HcQH5qDM_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_CnuHveKW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_WERiqjkE_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_ZhRsAVrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9AqJmsiD, HV_BINOP_MULTIPLY, 1, m, &cBinop_9AqJmsiD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tyhhezCV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_8N2fbHkN_sendMessage);
  cMsg_hjZbtsYB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_mTfbEyLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tt9f8ncp, HV_BINOP_MULTIPLY, 0, m, &cBinop_tt9f8ncp_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_n8zMVUzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_n9MvuERz_sendMessage(_c, 0, m);
  cMsg_0ceVDqXw_sendMessage(_c, 0, m);
  cMsg_rv63AVXc_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_OJI3ARSP_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_JPYfLtGj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0RDI5WV5_sendMessage);
  cMsg_BfXe7oXk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_Epu2GpzV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xDl3xNVo, 0, m, &cVar_xDl3xNVo_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_WLJrKhzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nhwdeego_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9FW719np_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_eeGgnpuB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9NMUKKgH_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1nnFBetS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_X610rijU_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_KnwVdMJR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MKRaMSPm_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nyajlf0t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UkS2Mx42_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_4HnKR9eN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mmnYDDww_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hSvhZ5dO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xX3pbldQ_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_iowdBzeS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_iIVB2FiY, HV_BINOP_MULTIPLY, 0, m, &cBinop_iIVB2FiY_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_cqhAUHVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_l8kAavAe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_36fxeYz9_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_6799I08L_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_KqoRWKV7_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_tIcOo80G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_3aalGI24_sendMessage);
  cMsg_SnS3HUlu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_RomVcN9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_K7O7r4cr, HV_BINOP_MULTIPLY, 0, m, &cBinop_K7O7r4cr_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_1TOqqhdW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_Rs1SktHX_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_z0U6KJ5i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YCrlYC0Q, HV_BINOP_MULTIPLY, 1, m, &cBinop_YCrlYC0Q_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_xYesSGj6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_Fr5iFwue_sendMessage);
  cMsg_JRYwJMcj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_68EiZkHo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QIpuN38m, HV_BINOP_MULTIPLY, 0, m, &cBinop_QIpuN38m_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_WpS5hsq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Q0lPu0hK_sendMessage(_c, 0, m);
  cMsg_CCr9o0bA_sendMessage(_c, 0, m);
  cMsg_I4Ly0VUW_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_ZE8SjIts_sendMessage);
}

void Heavy_WSTD_3Q::cReceive_Re0s4gjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_e6rpApYb_sendMessage);
  cMsg_EqllBlRF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_3Q::cReceive_7cLiOR54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Bj0VfxwX, 0, m, &cVar_Bj0VfxwX_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_3Q::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9;

  // input and output vars
  hv_bufferf_t O0, O1, O2, O3, O4, O5;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));
    __hv_zero_f(VOf(O2));
    __hv_zero_f(VOf(O3));
    __hv_zero_f(VOf(O4));
    __hv_zero_f(VOf(O5));

    // process all signal functions
    __hv_line_f(&sLine_iHAWnjhd, VOf(Bf0));
    __hv_line_f(&sLine_v9q9Nvkl, VOf(Bf1));
    __hv_line_f(&sLine_Gq8kq6bj, VOf(Bf2));
    __hv_line_f(&sLine_qmEGzyOo, VOf(Bf3));
    __hv_line_f(&sLine_1oazJ2JW, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_DyLaJ269, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_GnXgd6sr, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_eR7ZcX6W, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_EppcuUID, VOf(Bf1));
    __hv_line_f(&sLine_wGcy1KPF, VOf(Bf0));
    __hv_line_f(&sLine_Yhy2wQ9Y, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_0Ncm1ImX, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_LT35FONL, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_PfN9zJXM, VOf(Bf5));
    __hv_line_f(&sLine_ywm8N8Ug, VOf(Bf1));
    __hv_line_f(&sLine_hpyNO9jx, VOf(Bf2));
    __hv_line_f(&sLine_ULzSpYVr, VOf(Bf4));
    __hv_line_f(&sLine_KzYakTuc, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_g2GvB5Ri, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_h9F5UT06, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_hFefh3BO, VOf(Bf6));
    __hv_line_f(&sLine_yPtnnMvF, VOf(Bf2));
    __hv_line_f(&sLine_DKt35oPf, VOf(Bf1));
    __hv_line_f(&sLine_Ppc3quhn, VOf(Bf5));
    __hv_line_f(&sLine_vkeTA81Q, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_qMltZ4Me, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_3WzIuWuY, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_J8tltp85, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_CcCXTdn6, VOf(Bf2));
    __hv_line_f(&sLine_o4wkmNiL, VOf(Bf6));
    __hv_line_f(&sLine_uctpVg2V, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_moMyHu2Y, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_BurItLyE, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_dCF53TD5, VOf(Bf8));
    __hv_line_f(&sLine_m4Y6EUBk, VOf(Bf2));
    __hv_line_f(&sLine_QNMgRTPC, VOf(Bf1));
    __hv_line_f(&sLine_8ZooiglC, VOf(Bf7));
    __hv_line_f(&sLine_OhoyiwcX, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_HfgzVHKd, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_varread_f(&sVarf_l8fHoiTF, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf7), VIf(O5), VOf(O5));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf6), VIf(O3), VOf(O3));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf4), VIf(O4), VOf(O4));
    __hv_add_f(VIf(Bf0), VIf(O2), VOf(O2));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
    __hv_store_f(outputBuffers[2]+n, VIf(O2));
    __hv_store_f(outputBuffers[3]+n, VIf(O3));
    __hv_store_f(outputBuffers[4]+n, VIf(O4));
    __hv_store_f(outputBuffers[5]+n, VIf(O5));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_3Q::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 6 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(6*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);
  bOut[2] = outputBuffers+(2*n4);
  bOut[3] = outputBuffers+(3*n4);
  bOut[4] = outputBuffers+(4*n4);
  bOut[5] = outputBuffers+(5*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_3Q::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 6 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(6*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  
  // interleave the heavy output into the output buffer
  for (int i = 0; i < 6; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+6*j] = bOut[i*n4+j];
    }
  }

  return n;
}
